Stan Math Library: stan/math/memory/stack_alloc.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces | Functions
stack_alloc.hpp File Reference
`#include <stdint.h>`
`#include <stan/math/prim/scal/meta/likely.hpp>`
`#include <cstdlib>`
`#include <cstddef>`
`#include <sstream>`
`#include <stdexcept>`
`#include <vector>`

Go to the source code of this file.

## Classes
class | stan::math::stack_alloc
| An instance of this class provides a memory pool through which blocks of raw memory may be allocated and then collected simultaneously. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
bool | stan::math::is_aligned (T *ptr, unsigned int bytes_aligned)
| Return `true` if the specified pointer is aligned on the number of bytes. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.